
Examples
========

Example Projects
^^^^^^^^^^^^^^^^

.. glossary::

    `Rocketry with FastAPI (and React) <https://github.com/Miksus/rocketry-with-fastapi>`_

        Rocketry template that has FastAPI (REST API) integrated and also has web UI built
        with React.

Example Snippets
^^^^^^^^^^^^^^^^

**Minimal example:**

.. literalinclude:: /code/demos/minimal.py
    :language: py

**Basic example:**

.. literalinclude:: /code/demos/basic.py
    :language: py

**Intermediate example:**

.. literalinclude:: /code/demos/intermediate.py
    :language: py

**Advanced example:**

.. literalinclude:: /code/demos/advanced.py
    :language: py